@@ -32,15 +32,18 @@ from cachelib import FileSystemCache, NullCache
 
 from keep import utils as keep_utils
 
-from pygments import highlight
 from pygments.lexers import guess_lexer, get_lexer_by_name
-from pygments.formatters.terminal import TerminalFormatter
 from pygments.util import ClassNotFound
+from rich.syntax import Syntax
+from rich.console import Console
 
 from pyquery import PyQuery as pq
 from requests.exceptions import ConnectionError as RequestsConnectionError
 from requests.exceptions import SSLError
 
+from colorama import init
+init()
+
 from howdoi import __version__
 from howdoi.errors import GoogleValidationError, BingValidationError, DDGValidationError
 
@@ -171,11 +174,6 @@ def get_proxies():
     return filtered_proxies
 
 
-def _format_url_to_filename(url, file_ext='html'):
-    filename = ''.join(ch for ch in url if ch.isalnum())
-    return filename + '.' + file_ext
-
-
 def _get_result(url):
     try:
         resp = howdoi_session.get(url, headers={'User-Agent': _random_choice(USER_AGENTS)},
@@ -319,12 +317,11 @@ def _format_output(args, code):
     if not args['color']:
         return code
     lexer = None
-
     # try to find a lexer using the StackOverflow tags
     # or the query arguments
     for keyword in args['query'].split() + args['tags']:
         try:
-            lexer = get_lexer_by_name(keyword)
+            lexer = get_lexer_by_name(keyword).name
             break
         except ClassNotFound:
             pass
@@ -332,13 +329,15 @@ def _format_output(args, code):
     # no lexer found above, use the guesser
     if not lexer:
         try:
-            lexer = guess_lexer(code)
+            lexer = guess_lexer(code).name
         except ClassNotFound:
             return code
 
-    return highlight(code,
-                     lexer,
-                     TerminalFormatter(bg='dark'))
+    syntax = Syntax(code, lexer, background_color="default", line_numbers=False)
+    console = Console(record=True)
+    with console.capture() as capture:
+        console.print(syntax)
+    return capture.get()
 
 
 def _is_question(link):
@@ -812,12 +811,16 @@ def command_line_runner():  # pylint: disable=too-many-return-statements,too-man
     if os.getenv('HOWDOI_COLORIZE'):
         args['color'] = True
 
-    utf8_result = howdoi(args).encode('utf-8', 'ignore')
-    if sys.version < '3':
-        print(utf8_result)
+    howdoi_result = howdoi(args)
+
+    if os.name == 'nt':
+        # Windows
+        print(howdoi_result)
     else:
+        utf8_result = howdoi_result.encode('utf-8', 'ignore')
         # Write UTF-8 to stdout: https://stackoverflow.com/a/3603160
         sys.stdout.buffer.write(utf8_result)
+
     # close the session to release connection
     howdoi_session.close()
 
